@@ -501,7 +501,6 @@ impl Node {
             NodeDuty::IncrementFullNodeCount { node_id } => {
                 let elder = self.role.as_elder_mut()?.clone();
                 let handle = tokio::spawn(async move {
-                    let propose_offline = NodeDuty::ProposeOffline(vec![node_id.into()]);
                     elder
                         .meta_data
                         .write()
@@ -509,10 +508,7 @@ impl Node {
                         .increase_full_node_count(node_id)
                         .await?;
                     // Accept a new node in place for the full node.
-                    Ok(NodeTask::from(vec![
-                        NodeDuty::SetNodeJoinsAllowed(true),
-                        propose_offline,
-                    ]))
+                    Ok(NodeTask::from(vec![NodeDuty::SetNodeJoinsAllowed(true)]))
                 });
                 Ok(NodeTask::Thread(handle))
             }
@@ -587,7 +583,11 @@ impl Node {
                         ]
                     } else {
                         let targets = network_api
-                            .get_closest_elders_to(&data_section_addr, DATA_SECTION_TARGET_COUNT)
+                            .get_closest_elders_to(
+                                &data_section_addr,
+                                msg_id,
+                                DATA_SECTION_TARGET_COUNT,
+                            )
                             .await?;
                         vec![NodeDuty::SendToNodes {
                             msg: NodeMsg::NodeQuery {
